TODOs for MasterPiece
=====================

This will be an exceptionally well structured priorized list of TODOs:

* Docstrings contain many TODO:s which Sphinx should pick up and include with this file. Does not, fix please.

* The docs/conf.py file contains both masterpiece framework-specific and plugin-specific
  information (e.g., copyright and author). Copying the entire conf.py to every project
  built on masterpiece is a bad habit. Implement a base configuration class from which
  plugin developers can derive their own conf.py files, containing only plugin-specific
  info (DRY principle).



The following items have been extraced from the source code:

.. todolist::
